==> pymatviz-0.15.1-py3-none-any.whl: pymatviz/colors.py <==
"""Colors used in pymatviz."""

from __future__ import annotations

from typing import TYPE_CHECKING


if TYPE_CHECKING:
    from typing import Final

    from pymatviz.typing import Rgb256ColorType, RgbColorType


# Element type based colors
ELEM_TYPE_COLORS: Final = {
    "Diatomic Nonmetal": "green",
    "Noble Gas": "purple",
    "Alkali Metal": "red",
    "Alkaline Earth Metal": "orange",
    "Metalloid": "darkgreen",
    "Polyatomic Nonmetal": "teal",
    "Transition Metal": "blue",
    "Post Transition Metal": "cyan",
    "Lanthanide": "brown",
    "Actinide": "gray",
    "Nonmetal": "green",
    "Halogen": "teal",
    "Metal": "lightblue",
    "Alkaline Metal": "magenta",
    "Transactinide": "olive",
}

# The following element-based colors are copied from elementari:
# https://github.com/janosh/elementari/blob/85a044cd/src/lib/colors.ts#L20-L242
ELEM_COLORS_JMOL_256: dict[str, Rgb256ColorType] = {
    "H": (255, 255, 255),
    "He": (217, 255, 255),
    "Li": (204, 128, 255),
    "Be": (194, 255, 0),
    "B": (255, 181, 181),
    "C": (144, 144, 144),
    "N": (48, 80, 248),
    "O": (255, 13, 13),
    "F": (144, 224, 80),
    "Ne": (179, 227, 245),
    "Na": (171, 92, 242),
    "Mg": (138, 255, 0),
    "Al": (191, 166, 166),
    "Si": (240, 200, 160),
    "P": (255, 128, 0),
    "S": (255, 255, 48),
    "Cl": (31, 240, 31),
    "Ar": (128, 209, 227),
    "K": (143, 64, 212),
    "Ca": (61, 255, 0),
    "Sc": (230, 230, 230),
    "Ti": (191, 194, 199),
    "V": (166, 166, 171),
    "Cr": (138, 153, 199),
    "Mn": (156, 122, 199),
    "Fe": (224, 102, 51),
    "Co": (240, 144, 160),
    "Ni": (80, 208, 80),
    "Cu": (200, 128, 51),
    "Zn": (125, 128, 176),
    "Ga": (194, 143, 143),
    "Ge": (102, 143, 143),
    "As": (189, 128, 227),
    "Se": (255, 161, 0),
    "Br": (166, 41, 41),
    "Kr": (92, 184, 209),
    "Rb": (112, 46, 176),
    "Sr": (0, 255, 0),
    "Y": (148, 255, 255),
    "Zr": (148, 224, 224),
    "Nb": (115, 194, 201),
    "Mo": (84, 181, 181),
    "Tc": (59, 158, 158),
    "Ru": (36, 143, 143),
    "Rh": (10, 125, 140),
    "Pd": (0, 105, 133),
    "Ag": (192, 192, 192),
    "Cd": (255, 217, 143),
    "In": (166, 117, 115),
    "Sn": (102, 128, 128),
    "Sb": (158, 99, 181),
    "Te": (212, 122, 0),
    "I": (148, 0, 148),
    "Xe": (66, 158, 176),
    "Cs": (87, 23, 143),
    "Ba": (0, 201, 0),
    "La": (112, 212, 255),
    "Ce": (255, 255, 199),
    "Pr": (217, 255, 199),
    "Nd": (199, 255, 199),
    "Pm": (163, 255, 199),
    "Sm": (143, 255, 199),
    "Eu": (97, 255, 199),
    "Gd": (69, 255, 199),
    "Tb": (48, 255, 199),
    "Dy": (31, 255, 199),
    "Ho": (0, 255, 156),
    "Er": (0, 230, 117),
    "Tm": (0, 212, 82),
    "Yb": (0, 191, 56),
    "Lu": (0, 171, 36),
    "Hf": (77, 194, 255),
    "Ta": (77, 166, 255),
    "W": (33, 148, 214),
    "Re": (38, 125, 171),
    "Os": (38, 102, 150),
    "Ir": (23, 84, 135),
    "Pt": (208, 208, 224),
    "Au": (255, 209, 35),
    "Hg": (184, 184, 208),
    "Tl": (166, 84, 77),
    "Pb": (87, 89, 97),
    "Bi": (158, 79, 181),
    "Po": (171, 92, 0),
    "At": (117, 79, 69),
    "Rn": (66, 130, 150),
    "Fr": (66, 0, 102),
    "Ra": (0, 125, 0),
    "Ac": (112, 171, 250),
    "Th": (0, 186, 255),
    "Pa": (0, 161, 255),
    "U": (0, 143, 255),
    "Np": (0, 128, 255),
    "Pu": (0, 107, 255),
    "Am": (84, 92, 242),
    "Cm": (120, 92, 227),
    "Bk": (138, 79, 227),
    "Cf": (161, 54, 212),
    "Es": (179, 31, 212),
    "Fm": (179, 31, 186),
    "Md": (179, 13, 166),
    "No": (189, 13, 135),
    "Lr": (199, 0, 102),
    "Rf": (204, 0, 89),
    "Db": (209, 0, 79),
    "Sg": (217, 0, 69),
    "Bh": (224, 0, 56),
    "Hs": (230, 0, 46),
    "Mt": (235, 0, 38),
}

# Scale color value to [0, 1] for matplotlib
ELEM_COLORS_JMOL: dict[str, RgbColorType] = {
    elem: (r / 255, g / 255, b / 255)
    for elem, (r, g, b) in ELEM_COLORS_JMOL_256.items()
}

ELEM_COLORS_VESTA_256: dict[str, Rgb256ColorType] = {
    "Ac": (112, 171, 250),
    "Ag": (192, 192, 192),
    "Al": (129, 178, 214),
    "Am": (84, 92, 242),
    "Ar": (207, 254, 196),
    "As": (116, 208, 87),
    "At": (117, 79, 69),
    "Au": (255, 209, 35),
    "B": (31, 162, 15),
    "Ba": (0, 201, 0),
    "Be": (94, 215, 123),
    "Bh": (224, 0, 56),
    "Bi": (158, 79, 181),
    "Bk": (138, 79, 227),
    "Br": (126, 49, 2),
    "C": (76, 76, 76),
    "Ca": (90, 150, 189),
    "Cd": (255, 217, 143),
    "Ce": (255, 255, 199),
    "Cf": (161, 54, 212),
    "Cl": (49, 252, 2),
    "Cm": (120, 92, 227),
    "Co": (0, 0, 175),
    "Cr": (0, 0, 158),
    "Cs": (87, 23, 143),
    "Cu": (34, 71, 220),
    "Db": (209, 0, 79),
    "Dy": (31, 255, 199),
    "Er": (0, 230, 117),
    "Es": (179, 31, 212),
    "Eu": (97, 255, 199),
    "F": (176, 185, 230),
    "Fe": (181, 113, 0),
    "Fm": (179, 31, 186),
    "Fr": (66, 0, 102),
    "Ga": (158, 227, 115),
    "Gd": (69, 255, 199),
    "Ge": (126, 110, 166),
    "H": (255, 204, 204),
    "He": (252, 232, 206),
    "Hf": (77, 194, 255),
    "Hg": (184, 184, 208),
    "Ho": (0, 255, 156),
    "Hs": (230, 0, 46),
    "I": (148, 0, 148),
    "In": (166, 117, 115),
    "Ir": (23, 84, 135),
    "K": (161, 33, 246),
    "Kr": (250, 193, 243),
    "La": (90, 196, 73),
    "Li": (134, 223, 115),
    "Lr": (199, 0, 102),
    "Lu": (0, 171, 36),
    "Md": (179, 13, 166),
    "Mg": (251, 123, 21),
    "Mn": (167, 8, 157),
    "Mo": (84, 181, 181),
    "Mt": (235, 0, 38),
    "N": (176, 185, 230),
    "Na": (249, 220, 60),
    "Nb": (115, 194, 201),
    "Nd": (199, 255, 199),
    "Ne": (254, 55, 181),
    "Ni": (183, 187, 189),
    "No": (189, 13, 135),
    "Np": (0, 128, 255),
    "O": (254, 3, 0),
    "Os": (38, 102, 150),
    "P": (192, 156, 194),
    "Pa": (0, 161, 255),
    "Pb": (87, 89, 97),
    "Pd": (0, 105, 133),
    "Pm": (163, 255, 199),
    "Po": (171, 92, 0),
    "Pr": (217, 255, 199),
    "Pt": (208, 208, 224),
    "Pu": (0, 107, 255),
    "Ra": (0, 125, 0),
    "Rb": (112, 46, 176),
    "Re": (38, 125, 171),
    "Rf": (204, 0, 89),
    "Rh": (10, 125, 140),
    "Rn": (66, 130, 150),
    "Ru": (36, 143, 143),
    "S": (255, 250, 0),
    "Sb": (158, 99, 181),
    "Sc": (181, 99, 171),
    "Se": (154, 239, 15),
    "Sg": (217, 0, 69),
    "Si": (27, 59, 250),
    "Sm": (143, 255, 199),
    "Sn": (154, 142, 185),
    "Sr": (0, 255, 0),
    "Ta": (77, 166, 255),
    "Tb": (48, 255, 199),
    "Tc": (59, 158, 158),
    "Te": (212, 122, 0),
    "Th": (0, 186, 255),
    "Ti": (120, 202, 255),
    "Tl": (166, 84, 77),
    "Tm": (0, 212, 82),
    "U": (0, 143, 255),
    "V": (229, 25, 0),
    "W": (33, 148, 214),
    "Xe": (66, 158, 176),
    "Y": (148, 255, 255),
    "Yb": (0, 191, 56),
    "Zn": (143, 143, 129),
    "Zr": (0, 255, 0),
}

ELEM_COLORS_VESTA: dict[str, RgbColorType] = {
    elem: (r / 255, g / 255, b / 255)
    for elem, (r, g, b) in ELEM_COLORS_VESTA_256.items()
}


# High-contrast color scheme optimized for metal alloys while preserving some familiar
# colors. Merge with ELEM_COLORS_VESTA to get a complete color scheme while only
# overriding metal colors.
ELEM_COLORS_ALLOY_256: dict[str, Rgb256ColorType] = ELEM_COLORS_VESTA_256 | {
    # Alkali metals - bright purples
    "Li": (0, 53, 0),  # Bright purple
    "Na": (0, 41, 255),  # Deep purple
    "K": (0, 255, 0),  # Royal purple
    "Rb": (0, 255, 255),  # Dark purple
    "Cs": (255, 0, 0),  # Deep violet
    # Alkaline earth metals - yellows/oranges
    "Be": (255, 0, 255),  # Golden yellow
    "Mg": (255, 255, 0),  # Dark orange
    "Ca": (255, 255, 255),  # Bright orange
    "Sr": (38, 154, 0),  # Red-orange
    "Ba": (0, 150, 255),  # Pure red
    # Transition metals - maximizing contrast
    "Sc": (207, 26, 128),  # Light gray (from JMOL)
    "Ti": (216, 219, 127),  # Purple (changed from blue for more contrast with Zr)
    "V": (255, 150, 0),  # Pink
    "Cr": (197, 163, 255),  # Bright green
    "Mn": (0, 46, 133),  # Magenta
    "Fe": (0, 151, 134),  # Bright orange (changed from JMOL)
    "Co": (0, 255, 121),  # Deep blue
    "Ni": (99, 0, 62),  # Orange (changed from green for contrast with Zr)
    "Cu": (129, 0, 255),  # Brown (changed from JMOL)
    "Zn": (168, 74, 0),  # Light blue
    "Zr": (108, 96, 208),  # Cyan (kept)
    "Nb": (134, 228, 15),  # Purple (new)
    # Post-transition metals - earth tones
    "Al": (102, 211, 188),  # Gray (from JMOL)
    "Ga": (255, 121, 143),  # Rose
    "In": (131, 143, 93),  # Dusty rose
    "Sn": (197, 163, 255),  # Dark orange (changed from blue-gray for contrast with Zr)
    "Tl": (0, 46, 133),  # Terra cotta
    "Pb": (0, 151, 134),  # Dark gray
    "Bi": (0, 255, 121),  # Purple
    # Noble metals - preserving traditional colors
    "Ru": (99, 0, 62),  # Teal
    "Rh": (129, 0, 255),  # Hot pink
    "Pd": (168, 74, 0),  # Blue (from JMOL)
    "Ag": (108, 96, 208),  # Silver (from JMOL)
    "Os": (134, 228, 15),  # Blue (from JMOL)
    "Ir": (102, 211, 188),  # Dark blue (from JMOL)
    "Pt": (255, 121, 143),  # Light gray (from JMOL)
    "Au": (131, 143, 93),  # Gold (from JMOL)
}

ELEM_COLORS_ALLOY: dict[str, RgbColorType] = {
    elem: (r / 255, g / 255, b / 255)
    for elem, (r, g, b) in ELEM_COLORS_ALLOY_256.items()
}

==> pymatviz-0.16.0-py3-none-any.whl: pymatviz/colors.py <==
"""Colors used in pymatviz."""

from __future__ import annotations

from typing import TYPE_CHECKING


if TYPE_CHECKING:
    from typing import Final

    from pymatviz.typing import Rgb256ColorType, RgbColorType


# Element type based colors
ELEM_TYPE_COLORS: Final = {
    "Diatomic Nonmetal": "green",
    "Noble Gas": "purple",
    "Alkali Metal": "red",
    "Alkaline Earth Metal": "orange",
    "Metalloid": "darkgreen",
    "Polyatomic Nonmetal": "teal",
    "Transition Metal": "blue",
    "Post Transition Metal": "cyan",
    "Lanthanide": "brown",
    "Actinide": "gray",
    "Nonmetal": "green",
    "Halogen": "teal",
    "Metal": "lightblue",
    "Alkaline Metal": "magenta",
    "Transactinide": "olive",
}

# The following element-based colors are copied from elementari:
# https://github.com/janosh/elementari/blob/85a044cd/src/lib/colors.ts#L20-L242
ELEM_COLORS_JMOL_256: dict[str, Rgb256ColorType] = {
    "H": (255, 255, 255),
    "He": (217, 255, 255),
    "Li": (204, 128, 255),
    "Be": (194, 255, 0),
    "B": (255, 181, 181),
    "C": (144, 144, 144),
    "N": (48, 80, 248),
    "O": (255, 13, 13),
    "F": (144, 224, 80),
    "Ne": (179, 227, 245),
    "Na": (171, 92, 242),
    "Mg": (138, 255, 0),
    "Al": (191, 166, 166),
    "Si": (240, 200, 160),
    "P": (255, 128, 0),
    "S": (255, 255, 48),
    "Cl": (31, 240, 31),
    "Ar": (128, 209, 227),
    "K": (143, 64, 212),
    "Ca": (61, 255, 0),
    "Sc": (230, 230, 230),
    "Ti": (191, 194, 199),
    "V": (166, 166, 171),
    "Cr": (138, 153, 199),
    "Mn": (156, 122, 199),
    "Fe": (224, 102, 51),
    "Co": (240, 144, 160),
    "Ni": (80, 208, 80),
    "Cu": (200, 128, 51),
    "Zn": (125, 128, 176),
    "Ga": (194, 143, 143),
    "Ge": (102, 143, 143),
    "As": (189, 128, 227),
    "Se": (255, 161, 0),
    "Br": (166, 41, 41),
    "Kr": (92, 184, 209),
    "Rb": (112, 46, 176),
    "Sr": (0, 255, 0),
    "Y": (148, 255, 255),
    "Zr": (148, 224, 224),
    "Nb": (115, 194, 201),
    "Mo": (84, 181, 181),
    "Tc": (59, 158, 158),
    "Ru": (36, 143, 143),
    "Rh": (10, 125, 140),
    "Pd": (0, 105, 133),
    "Ag": (192, 192, 192),
    "Cd": (255, 217, 143),
    "In": (166, 117, 115),
    "Sn": (102, 128, 128),
    "Sb": (158, 99, 181),
    "Te": (212, 122, 0),
    "I": (148, 0, 148),
    "Xe": (66, 158, 176),
    "Cs": (87, 23, 143),
    "Ba": (0, 201, 0),
    "La": (112, 212, 255),
    "Ce": (255, 255, 199),
    "Pr": (217, 255, 199),
    "Nd": (199, 255, 199),
    "Pm": (163, 255, 199),
    "Sm": (143, 255, 199),
    "Eu": (97, 255, 199),
    "Gd": (69, 255, 199),
    "Tb": (48, 255, 199),
    "Dy": (31, 255, 199),
    "Ho": (0, 255, 156),
    "Er": (0, 230, 117),
    "Tm": (0, 212, 82),
    "Yb": (0, 191, 56),
    "Lu": (0, 171, 36),
    "Hf": (77, 194, 255),
    "Ta": (77, 166, 255),
    "W": (33, 148, 214),
    "Re": (38, 125, 171),
    "Os": (38, 102, 150),
    "Ir": (23, 84, 135),
    "Pt": (208, 208, 224),
    "Au": (255, 209, 35),
    "Hg": (184, 184, 208),
    "Tl": (166, 84, 77),
    "Pb": (87, 89, 97),
    "Bi": (158, 79, 181),
    "Po": (171, 92, 0),
    "At": (117, 79, 69),
    "Rn": (66, 130, 150),
    "Fr": (66, 0, 102),
    "Ra": (0, 125, 0),
    "Ac": (112, 171, 250),
    "Th": (0, 186, 255),
    "Pa": (0, 161, 255),
    "U": (0, 143, 255),
    "Np": (0, 128, 255),
    "Pu": (0, 107, 255),
    "Am": (84, 92, 242),
    "Cm": (120, 92, 227),
    "Bk": (138, 79, 227),
    "Cf": (161, 54, 212),
    "Es": (179, 31, 212),
    "Fm": (179, 31, 186),
    "Md": (179, 13, 166),
    "No": (189, 13, 135),
    "Lr": (199, 0, 102),
    "Rf": (204, 0, 89),
    "Db": (209, 0, 79),
    "Sg": (217, 0, 69),
    "Bh": (224, 0, 56),
    "Hs": (230, 0, 46),
    "Mt": (235, 0, 38),
}

# Scale color value to [0, 1] for matplotlib
ELEM_COLORS_JMOL: dict[str, RgbColorType] = {
    elem: (r / 255, g / 255, b / 255)
    for elem, (r, g, b) in ELEM_COLORS_JMOL_256.items()
}

ELEM_COLORS_VESTA_256: dict[str, Rgb256ColorType] = {
    "Ac": (112, 171, 250),
    "Ag": (192, 192, 192),
    "Al": (129, 178, 214),
    "Am": (84, 92, 242),
    "Ar": (207, 254, 196),
    "As": (116, 208, 87),
    "At": (117, 79, 69),
    "Au": (255, 209, 35),
    "B": (31, 162, 15),
    "Ba": (0, 201, 0),
    "Be": (94, 215, 123),
    "Bh": (224, 0, 56),
    "Bi": (158, 79, 181),
    "Bk": (138, 79, 227),
    "Br": (126, 49, 2),
    "C": (76, 76, 76),
    "Ca": (90, 150, 189),
    "Cd": (255, 217, 143),
    "Ce": (255, 255, 199),
    "Cf": (161, 54, 212),
    "Cl": (49, 252, 2),
    "Cm": (120, 92, 227),
    "Co": (0, 0, 175),
    "Cr": (0, 0, 158),
    "Cs": (87, 23, 143),
    "Cu": (34, 71, 220),
    "Db": (209, 0, 79),
    "Dy": (31, 255, 199),
    "Er": (0, 230, 117),
    "Es": (179, 31, 212),
    "Eu": (97, 255, 199),
    "F": (176, 185, 230),
    "Fe": (181, 113, 0),
    "Fm": (179, 31, 186),
    "Fr": (66, 0, 102),
    "Ga": (158, 227, 115),
    "Gd": (69, 255, 199),
    "Ge": (126, 110, 166),
    "H": (255, 204, 204),
    "He": (252, 232, 206),
    "Hf": (77, 194, 255),
    "Hg": (184, 184, 208),
    "Ho": (0, 255, 156),
    "Hs": (230, 0, 46),
    "I": (148, 0, 148),
    "In": (166, 117, 115),
    "Ir": (23, 84, 135),
    "K": (161, 33, 246),
    "Kr": (250, 193, 243),
    "La": (90, 196, 73),
    "Li": (134, 223, 115),
    "Lr": (199, 0, 102),
    "Lu": (0, 171, 36),
    "Md": (179, 13, 166),
    "Mg": (251, 123, 21),
    "Mn": (167, 8, 157),
    "Mo": (84, 181, 181),
    "Mt": (235, 0, 38),
    "N": (176, 185, 230),
    "Na": (249, 220, 60),
    "Nb": (115, 194, 201),
    "Nd": (199, 255, 199),
    "Ne": (254, 55, 181),
    "Ni": (183, 187, 189),
    "No": (189, 13, 135),
    "Np": (0, 128, 255),
    "O": (254, 3, 0),
    "Os": (38, 102, 150),
    "P": (192, 156, 194),
    "Pa": (0, 161, 255),
    "Pb": (87, 89, 97),
    "Pd": (0, 105, 133),
    "Pm": (163, 255, 199),
    "Po": (171, 92, 0),
    "Pr": (217, 255, 199),
    "Pt": (208, 208, 224),
    "Pu": (0, 107, 255),
    "Ra": (0, 125, 0),
    "Rb": (112, 46, 176),
    "Re": (38, 125, 171),
    "Rf": (204, 0, 89),
    "Rh": (10, 125, 140),
    "Rn": (66, 130, 150),
    "Ru": (36, 143, 143),
    "S": (255, 250, 0),
    "Sb": (158, 99, 181),
    "Sc": (181, 99, 171),
    "Se": (154, 239, 15),
    "Sg": (217, 0, 69),
    "Si": (27, 59, 250),
    "Sm": (143, 255, 199),
    "Sn": (154, 142, 185),
    "Sr": (0, 255, 0),
    "Ta": (77, 166, 255),
    "Tb": (48, 255, 199),
    "Tc": (59, 158, 158),
    "Te": (212, 122, 0),
    "Th": (0, 186, 255),
    "Ti": (120, 202, 255),
    "Tl": (166, 84, 77),
    "Tm": (0, 212, 82),
    "U": (0, 143, 255),
    "V": (229, 25, 0),
    "W": (33, 148, 214),
    "Xe": (66, 158, 176),
    "Y": (148, 255, 255),
    "Yb": (0, 191, 56),
    "Zn": (143, 143, 129),
    "Zr": (0, 255, 0),
}

ELEM_COLORS_VESTA: dict[str, RgbColorType] = {
    elem: (r / 255, g / 255, b / 255)
    for elem, (r, g, b) in ELEM_COLORS_VESTA_256.items()
}


# High-contrast color scheme optimized for metal alloys while preserving some familiar
# colors. Merge with ELEM_COLORS_VESTA to get a complete color scheme while only
# overriding metal colors.
ELEM_COLORS_ALLOY_256: dict[str, Rgb256ColorType] = ELEM_COLORS_VESTA_256 | {
    # Alkali metals - bright purples
    "Li": (0, 53, 0),  # Dark green
    "Na": (0, 41, 255),  # Deep blue
    "K": (0, 255, 0),  # Bright green
    "Rb": (0, 255, 255),  # Cyan
    "Cs": (255, 0, 0),  # Bright red
    # Alkaline earth metals - yellows/oranges
    "Be": (255, 0, 255),  # Magenta
    "Mg": (255, 255, 0),  # Yellow
    "Ca": (255, 255, 255),  # White
    "Sr": (38, 154, 0),  # Green
    "Ba": (0, 150, 255),  # Blue
    # Transition metals - maximizing contrast
    "Sc": (207, 26, 128),  # Pink
    "Ti": (216, 219, 127),  # Light yellow-green
    "V": (255, 150, 0),  # Orange
    "Cr": (197, 163, 255),  # Light purple
    "Mn": (0, 46, 133),  # Dark blue
    "Fe": (0, 151, 134),  # Teal
    "Co": (0, 255, 121),  # Bright green
    "Ni": (99, 0, 62),  # Dark red/burgundy
    "Cu": (129, 0, 255),  # Purple
    "Zn": (168, 74, 0),  # Brown
    "Zr": (108, 96, 208),  # Medium blue-purple
    "Nb": (134, 228, 15),  # Lime green
    # Post-transition metals - earth tones
    "Al": (102, 211, 188),  # Light teal
    "Ga": (255, 121, 143),  # Pink
    "In": (131, 143, 93),  # Olive green
    "Sn": (197, 163, 255),  # Light purple
    "Tl": (0, 46, 133),  # Dark blue
    "Pb": (0, 151, 134),  # Teal
    "Bi": (0, 255, 121),  # Bright green
    # Noble metals - preserving traditional colors
    "Ru": (99, 0, 62),  # Dark red/burgundy
    "Rh": (129, 0, 255),  # Purple
    "Pd": (168, 74, 0),  # Brown
    "Ag": (108, 96, 208),  # Medium blue-purple
    "Os": (134, 228, 15),  # Lime green
    "Ir": (102, 211, 188),  # Light teal
    "Pt": (255, 121, 143),  # Pink
    "Au": (131, 143, 93),  # Olive green
}

ELEM_COLORS_ALLOY: dict[str, RgbColorType] = {
    elem: (r / 255, g / 255, b / 255)
    for elem, (r, g, b) in ELEM_COLORS_ALLOY_256.items()
}
